@@ -1,7 +1,7 @@
 #
 # fields  is a package for analysis of spatial data written for
 # the R software environment.
-# Copyright (C) 2021 Colorado School of Mines
+# Copyright (C) 2022 Colorado School of Mines
 # 1500 Illinois St., Golden, CO 80401
 # Contact: Douglas Nychka,  douglasnychka@gmail.edu,
 #
@@ -21,6 +21,7 @@
 ##END HEADER
 circulantEmbeddingSetup <- function( 
      grid, M = NULL, 
+     mKrigObject=NULL, 
      cov.function="stationary.cov", cov.args=NULL,
      delta=NULL, ...) {
     #
@@ -28,7 +29,14 @@ circulantEmbeddingSetup <- function(
     # basically need to enlarge domain and find the FFT of the
     # covariance
     #
+    if( !is.null(mKrigObject)){
+    #  mine the mKrigObject to get the covariance model.  
+        cov.args<- mKrigObject$args
+        cov.function<- mKrigObject$cov.function.name
+    }
+    else{
     cov.args<-c( cov.args, list(...))
+    }
         L<- length( grid)
         dx<- rep( NA, L)
         m<- rep( NA, L)
@@ -76,22 +84,26 @@ circulantEmbeddingSetup <- function(
         # here is where the actual covariance form is used
         # note passed arguments from call for parameters etc.
         #
-        out<- do.call(cov.function, c(cov.args, list(x1 = bigGrid, x2 = center)))  
+        out<- do.call(cov.function, c(cov.args, 
+                                      list(x1 = bigGrid, x2 = center)))  
         # coerce to an array note that this depends on the bigIndex varying in the right way
         out<- array( c(out),M)
-        
         #
-        # this normalization can be skipped because the simulated field 
-        # is stationary and periodic.
-        # for example
-        # wght <- fft(out)/prod(M)
-        # OLD CODE:
         # a simple way to normalize. This could be avoided by
         # translating image from the center ...
         # add to the middle point in the array -- matches the center from above
          temp <- array( 0, M)
          temp[rbind( MCenter)] <- 1
          wght <- fft(out)/(fft(temp) * prod(M))
+         if( any( Re(wght) < 0 ) ){
+           cat("summary of real part of weights", fill=TRUE)
+           print( stats(Re(wght)))
+           stop(" 
+                some weights appear to be less than zero.
+              This can be due to the correlation range being too large for the grid.
+                Try increasing the spatial domain or decreasing the number of grid points.
+                ")
+         }
         
         #
         # wght is the discrete FFT for the covariance suitable for fast
