@@ -1,7 +1,7 @@
 #
 # fields  is a package for analysis of spatial data written for
 # the R software environment.
-# Copyright (C) 2021 Colorado School of Mines
+# Copyright (C) 2022 Colorado School of Mines
 # 1500 Illinois St., Golden, CO 80401
 # Contact: Douglas Nychka,  douglasnychka@gmail.edu,
 #
@@ -26,7 +26,7 @@ compactToMat = function(compactMat, diagVal=0, lower.tri=FALSE, upper.tri=TRUE)
   #lower.tri: if TRUE, fills in lower tringular portion of the matrix
   #upper.tri: if TRUE, fills in upper tringular portion of the matrix
   
-  if(class(compactMat) == 'dist') {
+  if( is(compactMat,"dist") ) {
     n <- attr(compactMat, "Size")
   } else { # (n^2 - n)/2 = length(compactMat)
     stop("input matrix is not compact or is not of class \"dist\"")
