@@ -1,7 +1,7 @@
 #
 # fields  is a package for analysis of spatial data written for
 # the R software environment.
-# Copyright (C) 2021 Colorado School of Mines
+# Copyright (C) 2022 Colorado School of Mines
 # 1500 Illinois St., Golden, CO 80401
 # Contact: Douglas Nychka,  douglasnychka@gmail.edu,
 #
@@ -161,7 +161,7 @@ mKrigMLEJoint<- function(x, y, weights = rep(1, nrow(x)),  Z = NULL,
                     )
                   )
 # catch error in optim and return  
-  if( class(optimResults )=="try-error"){
+  if( is(optimResults, "try-error") ){
     cat("Error in call to optim", fill=TRUE) 
     out =list( summary = NA,
                lnLikeEvaluations = capture.evaluations[-1,],
