@@ -1,9 +1,9 @@
+#
 # fields  is a package for analysis of spatial data written for
-# the R software environment .
-# Copyright (C) 2018
-# University Corporation for Atmospheric Research (UCAR)
-# Contact: Douglas Nychka, nychka@ucar.edu,
-# National Center for Atmospheric Research, PO Box 3000, Boulder, CO 80307-3000
+# the R software environment.
+# Copyright (C) 2022 Colorado School of Mines
+# 1500 Illinois St., Golden, CO 80401
+# Contact: Douglas Nychka,  douglasnychka@gmail.edu,
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,7 +17,8 @@
 # You should have received a copy of the GNU General Public License
 # along with the R software environment if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-# or see http://www.r-project.org/Licenses/GPL-2    
+# or see http://www.r-project.org/Licenses/GPL-2
+##END HEADER
 "print.Krig" <- function(x, digits = 4, ...) {
     c1 <- "Number of Observations:"
     c2 <- length(x$residuals)
@@ -36,18 +37,18 @@
     c1 <- c(c1, "Residual degrees of freedom:")
     c2 <- c(c2, format(round(length(x$residuals) - x$eff.df, 
         1)))
-    c1 <- c(c1, "GCV estimate for sigma:")
-    c2 <- c(c2, format(signif(x$shat.GCV, digits)))
+    c1 <- c(c1, "GCV estimate for tau:")
+    c2 <- c(c2, format(signif(x$tauHat.GCV, digits)))
+    c1 <- c(c1, "MLE for tau:")
+    c2 <- c(c2, format(signif(x$tauHat.MLE, digits)))
     c1 <- c(c1, "MLE for sigma:")
-    c2 <- c(c2, format(signif(x$shat.MLE, digits)))
-    c1 <- c(c1, "MLE for rho:")
-    c2 <- c(c2, format(signif(x$rho.MLE, digits)))
+    c2 <- c(c2, format(signif(x$sigma.MLE, digits)))
     c1 <- c(c1, "lambda")
     c2 <- c(c2, format(signif(x$lambda, 2)))
-    c1 <- c(c1, "User supplied rho")
-    c2 <- c(c2, format(signif(x$rho, digits)))
-    c1 <- c(c1, "User supplied sigma^2")
-    c2 <- c(c2, format(signif(x$sigma2, digits)))
+    c1 <- c(c1, "User supplied sigma")
+    c2 <- c(c2, format(signif(x$sigma, digits)))
+    c1 <- c(c1, "User supplied tau^2")
+    c2 <- c(c2, format(signif(x$tau2, digits)))
     sum <- cbind(c1, c2)
     dimnames(sum) <- list(rep("", dim(sum)[1]), rep("", dim(sum)[2]))
     cat("Call:\n")
