@@ -1,9 +1,9 @@
+#
 # fields  is a package for analysis of spatial data written for
-# the R software environment .
-# Copyright (C) 2018
-# University Corporation for Atmospheric Research (UCAR)
-# Contact: Douglas Nychka, nychka@ucar.edu,
-# National Center for Atmospheric Research, PO Box 3000, Boulder, CO 80307-3000
+# the R software environment.
+# Copyright (C) 2022 Colorado School of Mines
+# 1500 Illinois St., Golden, CO 80401
+# Contact: Douglas Nychka,  douglasnychka@gmail.edu,
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,8 +14,12 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
+# You should have received a copy of the GNU General Public License
+# along with the R software environment if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+# or see http://www.r-project.org/Licenses/GPL-2
+##END HEADER
 print.spatialProcessSummary <- function(x, digits = 4, ...) {
-  
   cat("CALL:\n")
   dput(x$call)
   cat("\n")
@@ -50,20 +54,28 @@ print.spatialProcessSummary <- function(x, digits = 4, ...) {
       }
     }
   }
+  cat( "Nonzero entries in covariance matrix ", x$nonzero.entries, fill=TRUE)
+  
   cat("\n")
-  cat(" SUMMARY FROM ML ESTIMATION:", fill=TRUE)
-  if( !is.null( x$MLEpars)){
-    cat("  parameters found from optim: ", x$MLEpars, fill=TRUE )
-    cat(" sigma and rho found analytically", fill=TRUE)
+  cat("SUMMARY FROM Max. Likelihood ESTIMATION:", fill=TRUE)
+  
+  if( !is.null( x$MLEInfo) ){
+    cat("Parameters found from optim: ", fill=TRUE )
+    print( x$MLESummary[x$MLEpars] )
+    cat("Approx. confidence intervals for MLE(s) ", fill=TRUE )
+    print( x$CITable)
+    
+    cat("\n")
+    cat(" Note: MLEs for  tau and sigma found analytically from lambda", fill=TRUE)
     cat("\n")
-    print( x$MLESummary)
   }
   else{
-    cat(" lambda is fixed: ", fill=TRUE)
-    cat(" sigma and rho  analytically  derived from lambda", fill=TRUE)
+    cat(" lambda and range are supplied : ", fill=TRUE)
+    cat(" tau and sigma  analytically  derived from lambda", fill=TRUE)
     cat("\n")
-    print( x$MLESummary)
   }
+  cat("Summary from estimation:", fill=TRUE)
+  print( x$MLESummary)
  
   invisible(x)
 }
