@@ -1,9 +1,9 @@
+#
 # fields  is a package for analysis of spatial data written for
-# the R software environment .
-# Copyright (C) 2018
-# University Corporation for Atmospheric Research (UCAR)
-# Contact: Douglas Nychka, nychka@ucar.edu,
-# National Center for Atmospheric Research, PO Box 3000, Boulder, CO 80307-3000
+# the R software environment.
+# Copyright (C) 2022 Colorado School of Mines
+# 1500 Illinois St., Golden, CO 80401
+# Contact: Douglas Nychka,  douglasnychka@gmail.edu,
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,7 +17,8 @@
 # You should have received a copy of the GNU General Public License
 # along with the R software environment if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-# or see http://www.r-project.org/Licenses/GPL-2    
+# or see http://www.r-project.org/Licenses/GPL-2
+##END HEADER
 printGCVWarnings<- function( Table, method="all"){
  ind<- Table$Warning
  if( method=="user"){
@@ -41,8 +42,8 @@ printGCVWarnings<- function( Table, method="all"){
  "(GCV) Generalized Cross-Validation ",
  "(GCV.model) Generalized Cross-Validation on replicate means ",
  "(GCV.one) Generalized Cross-Validation on individual observations ",
- "(RMSE) Matching estimate of sigma to supplied rmse ",
- "Matching estimate of sigma to that from replicated observations",
+ "(RMSE) Matching estimate of tau to supplied rmse ",
+ "Matching estimate of tau to that from replicated observations",
  "(REML) Restricted maximum likelihood ",
  "user supplied lambda"
   )
