@@ -1,9 +1,9 @@
+#
 # fields  is a package for analysis of spatial data written for
-# the R software environment .
-# Copyright (C) 2018
-# University Corporation for Atmospheric Research (UCAR)
-# Contact: Douglas Nychka, nychka@ucar.edu,
-# National Center for Atmospheric Research, PO Box 3000, Boulder, CO 80307-3000
+# the R software environment.
+# Copyright (C) 2022 Colorado School of Mines
+# 1500 Illinois St., Golden, CO 80401
+# Contact: Douglas Nychka,  douglasnychka@gmail.edu,
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,6 +14,11 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
+# You should have received a copy of the GNU General Public License
+# along with the R software environment if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+# or see http://www.r-project.org/Licenses/GPL-2
+##END HEADER
 summary.spatialProcess <- function(object, ...) {
 # output list
   outObject<- list()
@@ -51,23 +56,18 @@ summary.spatialProcess <- function(object, ...) {
     c2 <- c(c2, object$nZ)
   }
   
-  c1 <- c(c1, "MLE nugget variance ( sigma^2)")
-  c2 <- c(c2, signif(object$sigma.MLE.FULL^2, digits))
-    
-  c1 <- c(c1, "MLE process variance (rho)")
-  c2 <- c(c2, signif(object$rho.MLE.FULL, digits))
+   
+  c1 <- c(c1, "sigma Process stan. dev: ")
+  c2 <- c(c2, signif( sqrt(object$MLESummary["sigma2"]), digits))
   
-  c1 <- c(c1, "Value for lambda = sigma^2/rho")
-  c2 <- c(c2, signif(object$lambdaModel, digits))
+  c1 <- c(c1, "tau  Nugget stan. dev:")
+  c2 <- c(c2, signif(object$MLESummary["tau"], digits))
   
+  c1 <- c(c1, "lambda   tau^2/sigma^2: ")
+  c2 <- c(c2, signif(object$MLESummary["lambda"], digits))
   
-  c1 <- c(c1, "MLE range parameter (theta, units of distance): ")
-  c2 <- c(c2, signif(object$theta.MLE, digits))
-  
-  c1 <- c(c1, paste0( "Approx ", object$confidenceLevel,  "% CI for theta:  ") ) 
-  c2<-  c(c2, paste( "[",signif( object$theta.CI[1], digits), ",",
-                      signif( object$theta.CI[2], digits), "]"  ) 
-           )
+  c1 <- c(c1, "aRange parameter (in units of distance): ")
+  c2 <- c(c2, signif(object$MLESummary["aRange"], digits))
   
   if (!is.na(object$eff.df)) {
     c1 <- c(c1, "Approx.  degrees of freedom for curve")
@@ -79,13 +79,10 @@ summary.spatialProcess <- function(object, ...) {
     }
   }
   
-  c1 <- c(c1, "Nonzero entries in covariance")
-  c2 <- c(c2, object$nonzero.entries)
-  
   c1<- c(c1, "log Likelihood: " )
-  c2<- c( c2, object$lnProfileLike.FULL)
+  c2<- c( c2, object$summary["lnProfileLike.FULL"])
   c1<- c(c1, "log Likelihood REML: " )
-  c2<- c( c2, object$lnProfileREML.FULL)
+  c2<- c( c2, object$summary["lnProfileREML.FULL"])
   
   summaryStuff<-  cbind(c1, c2)
   dimnames(summaryStuff) <- list(rep("",
@@ -94,16 +91,24 @@ summary.spatialProcess <- function(object, ...) {
 ###########  
   outObject$summaryTable<- summaryStuff
   outObject$collapseFixedEffect<- object$collapseFixedEffect
+  outObject$CITable<- object$CITable
 ###########
+  if( !is.null( object$MLEInfo)){
   outObject$MLEpars<-  names( object$MLEInfo$pars.MLE) 
   outObject$MLESummary<- object$summary
+  }
+  else{
+    outObject$MLEpars <- NA
+    outObject$MLESummary<- object$summary
+  }
 ########### information for SE for fixed effects
+  if(!is.null(object$beta) ){
   if( outObject$collapseFixedEffect | (nData==1) ){
     outObject$fixedEffectsCov<- object$fixedEffectsCov
     SE<- sqrt(diag(outObject$fixedEffectsCov))
-    d.coef<-  object$d[,1]
-    pValue<- pnorm(abs(d.coef/SE), lower.tail = FALSE)*2
-    outObject$fixedEffectsTable<- cbind( signif(d.coef, digits), 
+    beta<-  object$beta[,1]
+    pValue<- pnorm(abs(beta/SE), lower.tail = FALSE)*2
+    outObject$fixedEffectsTable<- cbind( signif(beta, digits), 
                                       signif(SE, digits),
                                       signif(pValue, digits)
                                     )
@@ -116,13 +121,19 @@ summary.spatialProcess <- function(object, ...) {
     dimnames( outObject$fixedEffectsTable) <- list( outObject$fixedEffectNames,
                                            c("estimate", "SE", "pValue") )
   }
+  }
+  else{
+    outObject$fixedEffectsTable<- NA
+  }
 #####################
   outObject$nData <- nData
   outObject$call<- object$call
   outObject$cov.function<- object$cov.function
   outObject$args<- object$args
- 
-    class( outObject)<-"spatialProcessSummary"
+  outObject$nonzero.entries<- object$nonzero.entries
+  outObject$MLEInfo<- object$MLEInfo
+  
+  class( outObject)<-"spatialProcessSummary"
     
   return( outObject)
 
