@@ -1,9 +1,9 @@
+#
 # fields  is a package for analysis of spatial data written for
-# the R software environment .
-# Copyright (C) 2018
-# University Corporation for Atmospheric Research (UCAR)
-# Contact: Douglas Nychka, nychka@ucar.edu,
-# National Center for Atmospheric Research, PO Box 3000, Boulder, CO 80307-3000
+# the R software environment.
+# Copyright (C) 2022 Colorado School of Mines
+# 1500 Illinois St., Golden, CO 80401
+# Contact: Douglas Nychka,  douglasnychka@gmail.edu,
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,7 +17,8 @@
 # You should have received a copy of the GNU General Public License
 # along with the R software environment if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-# or see http://www.r-project.org/Licenses/GPL-2    
+# or see http://www.r-project.org/Licenses/GPL-2
+##END HEADER
 wendland.image.cov <- function(ind1, ind2, Y, cov.obj = NULL, 
     setup = FALSE, grid, M = NULL, N = NULL, cov.args=NULL, ...) {
     #
@@ -26,7 +27,13 @@ wendland.image.cov <- function(ind1, ind2, Y, cov.obj = NULL,
     # covariance
     #
     cov.args<-c( cov.args, list(...))
-    delta<- cov.args$theta 
+    #
+    # theta has been deopreciated.
+    if( !is.null(cov.args$theta )){
+      cov.args$aRange <- cov.args$theta
+    }
+    #
+    delta<- cov.args$aRange 
     if (is.null(cov.obj)) {
         dx <- grid$x[2] - grid$x[1]
         dy <- grid$y[2] - grid$y[1]
@@ -59,7 +66,7 @@ wendland.image.cov <- function(ind1, ind2, Y, cov.obj = NULL,
               sqrt(
                 matrix( xGrid^2, M,N, byrow=FALSE) +  matrix( yGrid^2, M,N, byrow=TRUE))              
   #      cat("Wendland", fill=TRUE)                     
-        out<- Wendland( bigDistance / cov.args$theta, dimension=2, k=cov.args$k )
+        out<- Wendland( bigDistance / cov.args$aRange, dimension=2, k=cov.args$k )
         temp <- matrix(0, nrow = M, ncol = N)
         #
         # a simple way to normalize. This could be avoided by
